@@ -2,7 +2,7 @@ package Mail::DMARC;
 use strict;
 use warnings;
 
-our $VERSION = '1.20240313';
+our $VERSION = '1.20240314';
 
 use Carp;
 our $psl_loads = 0;
@@ -309,7 +309,7 @@ Mail::DMARC - Perl implementation of DMARC
 
 =head1 VERSION
 
-version 1.20240313
+version 1.20240314
 
 =head1 SYNOPSIS
 
@@ -583,7 +583,7 @@ The DMARC spec is lengthy and evolving, making correctness a moving target. In c
 
 Providing an implementation of DMARC that SMTP utilities can utilize will aid DMARC adoption.
 
-The list of dependencies appears long because of reporting. If this module is used without reporting, the number of dependencies not included with perl is about 5. See the [Prereq] versus [Prereq / Recommends] sections in dist.ini.
+The list of dependencies appears long because of reporting. If this module is used without reporting, the number of dependencies not included with perl is about 5.
 
 =head2 Maintainable
 
